#
# spec file for package python3-Jinja2
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-Jinja2
Version:        2.8
Release:        5.2
Summary:        A fast and easy to use template engine written in pure Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://jinja.pocoo.org/
Source:         http://pypi.python.org/packages/source/J/Jinja2/Jinja2-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python3
BuildRequires:  python3-2to3
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires:       python3-MarkupSafe

%description
Jinja2 is a template engine written in pure Python.  It provides a Django
inspired non-XML syntax but supports inline expressions and an optional
sandboxed environment.  Here a small example of a Jinja template:

    {% extends 'base.html' %}
    {% block title %}Memberlist{% endblock %}
    {% block content %}
      <ul>
      {% for user in users %}
        <li><a href="{{ user.url }}">{{ user.username }}</a></li>
      {% endfor %}
      </ul>
    {% endblock %}

%package vim
Summary:        Jinja2 syntax files for Vim
License:        BSD-3-Clause
Group:          Productivity/Text/Editors
Requires:       %{name} = %{version}
Recommends:     vim

%description vim
Vim syntax highlighting scheme for Jinja2 templates.

%package emacs
Summary:        Jinja2 syntax files for Emacs
License:        GPL-2.0+
Group:          Productivity/Text/Editors
Requires:       %{name} = %{version}
Recommends:     emacs

%description emacs
Emacs syntax highlighting scheme for Jinja2 templates.

%prep
%setup -q -n Jinja2-%{version}

%build
python3 setup.py build
sed -i 's/\r$//' LICENSE # Fix wrong EOL encoding

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -Dm644 ext/Vim/jinja.vim %{buildroot}%{_datadir}/vim/site/syntax/jinja-python%{py3_ver}.vim # Install VIM syntax file
install -Dm644 ext/jinja.el %{buildroot}%{_datadir}/emacs/site-lisp/jinja-python%{py3_ver}.el # Install Emacs syntax file
%fdupes %{buildroot}%{_prefix}

%files
%defattr(-,root,root,-)
%doc AUTHORS CHANGES LICENSE artwork examples
%{python3_sitelib}/jinja2/
%{python3_sitelib}/Jinja2-%{version}-py*.egg-info

%files vim
%defattr(-,root,root,-)
%dir %{_datadir}/vim
%dir %{_datadir}/vim/site
%dir %{_datadir}/vim/site/syntax
%{_datadir}/vim/site/syntax/jinja-python%{py3_ver}.vim

%files emacs
%defattr(-,root,root,-)
%{_datadir}/emacs/site-lisp/jinja-python%{py3_ver}.el

%changelog
* Sat Aug  1 2015 arun@gmx.de
- specfile:
  * update copyright year
- update to version 2.8:
  * Added `target` parameter to urlize function.
  * Added support for `followsymlinks` to the file system loader.
  * The truncate filter now counts the length.
  * Added equalto filter that helps with select filters.
  * Changed cache keys to use absolute file names if available
    instead of load names.
  * Fixed loop length calculation for some iterators.
  * Changed how Jinja2 enforces strings to be native strings in
    Python 2 to work when people break their default encoding.
  * Added :func:`make_logging_undefined` which returns an undefined
    object that logs failures into a logger.
  * If unmarshalling of cached data fails the template will be
    reloaded now.
  * Implemented a block "set" tag.
  * Default cache size was incrased to 400 from a low 50.
  * Fixed "is number" test to accept long integers in all Python versions.
  * Changed "is number" to accept Decimal as a number.
  * Added a check for default arguments followed by non-default arguments. This
    change makes "{%% macro m(x, y=1, z) %%}...{%% endmacro %%}" a syntax error. The
    previous behavior for this code was broken anyway (resulting in the default
    value being applied to `y`).
  * Add ability to use custom subclasses of "jinja2.compiler.CodeGenerator" and
    "jinja2.runtime.Context" by adding two new attributes to the environment
    (`code_generator_class` and `context_class`) (pull request "#404").
  * added support for context/environment/evalctx decorator functions on
    the finalize callback of the environment.
  * escape query strings for urlencode properly.  Previously slashes were not
    escaped in that place.
  * Add 'base' parameter to 'int' filter.
* Tue Jul 15 2014 toddrme2178@gmail.com
- Update to 2.7.3
  - Security issue: Corrected the security fix for the cache folder.
    This fix was provided by RedHat.
* Thu May  8 2014 toddrme2178@gmail.com
- update to 2.7.2:
  - Prefix loader was not forwarding the locals properly to
    inner loaders.  This is now fixed.
  - Security issue: Changed the default folder for the filesystem cache to be
    user specific and read and write protected on UNIX systems.  See `Debian bug
    734747`_ for more information.
- avoid rebuildcycle with vim
* Thu Jan  9 2014 benoit.monin@gmx.fr
- update to upstream version 2.7.1:
  * Fixed a bug with `call_filter` not working properly on
    environment and context filters.
  * Fixed lack of Python 3 support for bytecode caches.
  * Reverted support for defining blocks in included templates as
    this broke existing templates for users.
  * Fixed some warnings with hashing of undefineds and nodes if
    Python is run with warnings for Python 3.
  * Added support for properly hashing undefined objects.
  * Fixed a bug with the title filter not working on already
    uppercase strings.
- additional changes from release 2.7.0:
  * Choice and prefix loaders now dispatch source and template
    lookup separately in order to work in combination with module
    loaders as advertised.
  * Fixed filesizeformat.
  * Added a non-silent option for babel extraction.
  * Added `urlencode` filter that automatically quotes values for
    URL safe usage with utf-8 as only supported encoding.  If
    applications want to change this encoding they can override
    the filter.
  * Added `keep-trailing-newline` configuration to environments
    and templates to optionally preserve the final trailing newline.
  * Accessing `last` on the loop context no longer causes the
    iterator to be consumed into a list.
  * Python requirement changed: 2.6, 2.7 or >= 3.3 are required now,
    supported by same source code, using the "six" compatibility
    library.
  * Allow `contextfunction` and other decorators to be applied
    to `__call__`.
  * Added support for changing from newline to different signs in
    the `wordwrap` filter.
  * Added support for ignoring memcache errors silently.
  * Added support for keeping the trailing newline in templates.
  * Added finer grained support for stripping whitespace on the
    left side of blocks.
  * Added `map`, `select`, `reject`, `selectattr` and `rejectattr`
    filters.
  * Added support for `loop.depth` to figure out how deep inside
    a recursive loop the code is.
  * Disabled py_compile for pypy and python 3.
- switch from distribute to setuptools
- remove Requires: python3 >= %%{py3_ver}: depreciated
- add MarkupSafe as a new runtime dependency for jinja >= 2.7
- drop JinjaTemplates.tmbundle.tar.gz from %%doc: removed upstream
* Fri Nov 30 2012 toddrme2178@gmail.com
- Fix building on openSUSE 12.1 and 12.2
* Thu Nov 22 2012 toddrme2178@gmail.com
- Remove openSUSE 11.4 spec file workarounds
* Mon Apr 30 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4 x86_64
* Thu Apr 26 2012 toddrme2178@gmail.com
- Add 2to3 buildrequires to allow for proper conversion of python 3
  version
* Mon Apr 23 2012 toddrme2178@gmail.com
- Add python 3 package
- Simplify vim plugin packaging
- Add suggests for vim and emacs in their respective
  packages
- Removed test for obsolete openSUSE version
